@@ -209,7 +209,6 @@ def build_bgp(anm):
             max_level = max(ibgp_levels)
             all_pairs = [ (s, t) for s in routers for t in routers if s != t]
             if max_level == 3:
-                c3_pairs = [(s, t) for (s, t) in all_pairs if s.ibgp_l3_cluster == t.ibgp_l3_cluster] # l3 cluster pairs
 
                 l1_l2_up_links = [ (s, t) for (s, t) in all_pairs if s.ibgp_level == 1 and t.ibgp_level == 2
                         and s.ibgp_l2_cluster == t.ibgp_l2_cluster]
@@ -241,11 +240,11 @@ def build_bgp(anm):
                         l2_cluster_devices = [r for r in l3_cluster_devices if r.ibgp_l2_cluster == l2_cluster]
 
                         if any(r.ibgp_level == 2 for r in l2_cluster_devices):
-                            log.info("L2 cluster %s in L3 cluster %s in ASN %s has l2 devices, not adding extra links" % (l2_cluster, l3_cluster, asn))
+                            log.debug("L2 cluster %s in L3 cluster %s in ASN %s has l2 devices, not adding extra links" % (l2_cluster, l3_cluster, asn))
                         else:
                             l1_routers = [r for r in l2_cluster_devices if r.ibgp_level == 1]
                             l3_routers = [r for r in l2_cluster_devices if r.ibgp_level == 3]
-                            log.info("L2 cluster %s in L3 cluster %s in ASN %s has no level 2 iBGP routers."
+                            log.debug("L2 cluster %s in L3 cluster %s in ASN %s has no level 2 iBGP routers."
                                     "Connecting level 1 routers (%s) to level 3 routers (%s)"
                                     % (l2_cluster, l3_cluster, asn, l1_routers, l3_routers))
 
