@@ -9,10 +9,10 @@ ws.onopen = function() {
     ws.send("overlay_list");
     ws.send("overlay_id=" + overlay_id);
     ws.send("ip_allocations");
-    $("#websocket_icon").html(' <i class="icon-circle " title="WebSocket Connected. Reload page to reconnect."></i>');
+    $("#websocket_icon").html(' <i class="icon-circle " title="WebSocket Connected."></i>');
 };
 ws.onclose = function () {
-    $("#websocket_icon").html(' <font color ="red"> <i class="icon-remove-sign " title="WebSocket Disconnected"></i></font>');
+    $("#websocket_icon").html(' <font color ="red"> <i class="icon-remove-sign " title="WebSocket Disconnected. Reload page to reconnect."></i></font>');
 };
 
 var icon_width = 45;
@@ -36,7 +36,6 @@ starting_hosts = [];
 
 ws.onmessage = function (evt) {
     var data = jQuery.parseJSON(evt.data);
-    console.log(data);
     //TODO: parse to see if valid traceroute path or other data
     if ("graph" in data) {
         if (overlay_id != "ip_allocations"){
@@ -484,7 +483,7 @@ var link_info = function(d) {
     text = source.id + " - " + target.id; //TODO: make sure all have labels from graphics appended overlay
 
     for (attr in d) {
-        if (d[attr] != null && d[attr] != "None" && attr != "source" & attr != "target" && attr != "edge_id") {
+        if (d[attr] != null && d[attr] != "None" && attr != "source" & attr != "target" && attr != "_interfaces" && attr != "edge_id") {
             text += ", " + attr + ": " + d[attr];
         }
     }
